@@ -2,8 +2,8 @@
 
 /*
  * $Author: tom $
- * $Date: 2011/05/17 23:51:26 $
- * $Revision: 1.93 $
+ * $Date: 2025/01/09 00:20:21 $
+ * $Revision: 1.101 $
  */
 
 #define YEAR2INDEX(year) (((year) >= 1900) ? ((year) - 1900) : (year))
@@ -11,7 +11,7 @@
 /*
  * Declare file local variables.
  */
-static char *monthsOfTheYear[] =
+static const char *monthsOfTheYear[] =
 {
    "NULL",
    "January",
@@ -68,7 +68,7 @@ DeclareCDKObjects (CALENDAR, Calendar, setCdk, Int);
 CDKCALENDAR *newCDKCalendar (CDKSCREEN *cdkscreen,
 			     int xplace,
 			     int yplace,
-			     char *title,
+			     const char *title,
 			     int day,
 			     int month,
 			     int year,
@@ -80,7 +80,7 @@ CDKCALENDAR *newCDKCalendar (CDKSCREEN *cdkscreen,
 			     boolean shadow)
 {
    /* *INDENT-EQLS* */
-   CDKCALENDAR *calendar = 0;
+   CDKCALENDAR *calendar = NULL;
    int parentWidth       = getmaxx (cdkscreen->window);
    int parentHeight      = getmaxy (cdkscreen->window);
    int boxWidth          = 24;
@@ -90,7 +90,7 @@ CDKCALENDAR *newCDKCalendar (CDKSCREEN *cdkscreen,
    int x;
    struct tm *dateInfo;
    time_t clck;
-   char *dayname         = "Su Mo Tu We Th Fr Sa ";
+   const char *dayname   = "Su Mo Tu We Th Fr Sa ";
    /* *INDENT-OFF* */
    static const struct { int from; int to; } bindings[] = {
 	    { 'T',		KEY_HOME },
@@ -102,8 +102,8 @@ CDKCALENDAR *newCDKCalendar (CDKSCREEN *cdkscreen,
    };
    /* *INDENT-ON* */
 
-   if ((calendar = newCDKObject (CDKCALENDAR, &my_funcs)) == 0)
-        return (0);
+   if ((calendar = newCDKObject (CDKCALENDAR, &my_funcs)) == NULL)
+        return (NULL);
 
    setCDKCalendarBox (calendar, Box);
 
@@ -124,10 +124,10 @@ CDKCALENDAR *newCDKCalendar (CDKSCREEN *cdkscreen,
    calendar->win = newwin (boxHeight, boxWidth, ypos, xpos);
 
    /* Is the window null? */
-   if (calendar->win == 0)
+   if (calendar->win == NULL)
    {
       destroyCDKObject (calendar);
-      return (0);
+      return (NULL);
    }
    keypad (calendar->win, TRUE);
 
@@ -145,7 +145,7 @@ CDKCALENDAR *newCDKCalendar (CDKSCREEN *cdkscreen,
    /* *INDENT-EQLS* Set the rest of the widget values. */
    ScreenOf (calendar)                  = cdkscreen;
    calendar->parent                     = cdkscreen->window;
-   calendar->shadowWin                  = 0;
+   calendar->shadowWin                  = NULL;
    calendar->xpos                       = xpos;
    calendar->ypos                       = ypos;
    calendar->boxWidth                   = boxWidth;
@@ -167,36 +167,36 @@ CDKCALENDAR *newCDKCalendar (CDKSCREEN *cdkscreen,
 				1, calendar->fieldWidth,
 				ypos + TitleLinesOf (calendar) + 1,
 				xpos + 1 + BorderOf (calendar));
-   if (calendar->labelWin == 0)
+   if (calendar->labelWin == NULL)
    {
       destroyCDKObject (calendar);
-      return (0);
+      return (NULL);
    }
 
    calendar->fieldWin = subwin (calendar->win,
 				7, 20,
 				ypos + TitleLinesOf (calendar) + 3,
 				xpos + calendar->xOffset);
-   if (calendar->fieldWin == 0)
+   if (calendar->fieldWin == NULL)
    {
       destroyCDKObject (calendar);
-      return (0);
+      return (NULL);
    }
 
    setCDKCalendarBox (calendar, Box);
 
    calendar->marker = typeCallocN (chtype, CALENDAR_LIMIT);
-   if (calendar->marker == 0)
+   if (calendar->marker == NULL)
    {
       destroyCDKObject (calendar);
-      return (0);
+      return (NULL);
    }
 
    /* If the day/month/year values were 0, then use today's date. */
    if ((calendar->day == 0) && (calendar->month == 0) && (calendar->year == 0))
    {
       time (&clck);
-      dateInfo = localtime (&clck);
+      dateInfo = gmtime (&clck);
 
       /* *INDENT-EQLS* */
       calendar->day    = dateInfo->tm_mday;
@@ -235,18 +235,17 @@ CDKCALENDAR *newCDKCalendar (CDKSCREEN *cdkscreen,
 time_t activateCDKCalendar (CDKCALENDAR *calendar, chtype *actions)
 {
    /* *INDENT-EQLS* */
-   chtype input = 0;
    boolean functionKey;
    time_t ret   = -1;
 
    /* Draw the widget. */
    drawCDKCalendar (calendar, ObjOf (calendar)->box);
 
-   if (actions == 0)
+   if (actions == NULL)
    {
       for (;;)
       {
-	 input = (chtype)getchCDKObject (ObjOf (calendar), &functionKey);
+	 chtype input = (chtype)getchCDKObject (ObjOf (calendar), &functionKey);
 
 	 /* Inject the character into the widget. */
 	 ret = injectCDKCalendar (calendar, input);
@@ -292,7 +291,7 @@ static int _injectCDKCalendar (CDKOBJS *object, chtype input)
    drawCDKCalendarField (widget);
 
    /* Check if there is a pre-process function to be called. */
-   if (PreProcessFuncOf (widget) != 0)
+   if (PreProcessFuncOf (widget) != NULL)
    {
       /* Call the pre-process function. */
       ppReturn = PreProcessFuncOf (widget) (vCALENDAR,
@@ -383,7 +382,7 @@ static int _injectCDKCalendar (CDKOBJS *object, chtype input)
       }
 
       /* Should we do a post-process? */
-      if (!complete && (PostProcessFuncOf (widget) != 0))
+      if (!complete && (PostProcessFuncOf (widget) != NULL))
       {
 	 PostProcessFuncOf (widget) (vCALENDAR,
 				     widget,
@@ -463,7 +462,7 @@ static void _drawCDKCalendar (CDKOBJS *object, boolean Box)
    int col;
 
    /* Is there a shadow? */
-   if (calendar->shadowWin != 0)
+   if (calendar->shadowWin != NULL)
    {
       drawShadow (calendar->shadowWin);
    }
@@ -501,7 +500,6 @@ static void drawCDKCalendarField (CDKCALENDAR *calendar)
    char *monthName = calendar->MonthName[calendar->month];
    int monthLength = getMonthLength (calendar->year, calendar->month);
    int yearIndex   = YEAR2INDEX (calendar->year);
-   int yearLen     = 0;
    int day;
    int row, col;
    int save_y      = -1;
@@ -549,8 +547,10 @@ static void drawCDKCalendarField (CDKCALENDAR *calendar)
    wrefresh (calendar->fieldWin);
 
    /* Draw the month in. */
-   if (calendar->labelWin != 0)
+   if (calendar->labelWin != NULL)
    {
+      int yearLen = 0;
+
       sprintf (temp, "%s %d,", monthName, calendar->day);
       writeChar (calendar->labelWin, 0, 0,
 		 temp, HORIZONTAL, 0, (int)strlen (temp));
@@ -608,7 +608,7 @@ void setCDKCalendarDate (CDKCALENDAR *calendar, int day, int month, int year)
     * the day/month/year values for the calendar.
     */
    time (&clck);
-   dateInfo = localtime (&clck);
+   dateInfo = gmtime (&clck);
 
    /* Set the date elements if we need too. */
    /* *INDENT-EQLS* */
@@ -700,13 +700,13 @@ boolean getCDKCalendarBox (CDKCALENDAR *calendar)
  */
 static void _setBKattrCalendar (CDKOBJS *object, chtype attrib)
 {
-   if (object != 0)
+   if (object != NULL)
    {
       CDKCALENDAR *widget = (CDKCALENDAR *)object;
 
       wbkgd (widget->win, attrib);
       wbkgd (widget->fieldWin, attrib);
-      if (widget->labelWin != 0)
+      if (widget->labelWin != NULL)
       {
 	 wbkgd (widget->labelWin, attrib);
       }
@@ -734,7 +734,7 @@ static void _eraseCDKCalendar (CDKOBJS *object)
  */
 static void _destroyCDKCalendar (CDKOBJS *object)
 {
-   if (object != 0)
+   if (object != NULL)
    {
       CDKCALENDAR *calendar = (CDKCALENDAR *)object;
       int x;
@@ -791,7 +791,7 @@ chtype getCDKCalendarMarker (CDKCALENDAR *calendar, int day, int month, int year
    chtype result = 0;
 
    year = YEAR2INDEX (year);
-   if (calendar->marker != 0)
+   if (calendar->marker != NULL)
       result = CALENDAR_CELL (calendar, day, month, year);
    return result;
 }
@@ -808,7 +808,7 @@ void removeCDKCalendarMarker (CDKCALENDAR *calendar, int day, int month, int yea
 /*
  * This function sets the month name.
  */
-void setCDKCalendarMonthsNames (CDKCALENDAR *calendar, char **months)
+void setCDKCalendarMonthsNames (CDKCALENDAR *calendar, CDK_CSTRING2 months)
 {
    int x;
 
@@ -822,7 +822,7 @@ void setCDKCalendarMonthsNames (CDKCALENDAR *calendar, char **months)
 /*
  * This function sets the day's name.
  */
-void setCDKCalendarDaysNames (CDKCALENDAR *calendar, char *days)
+void setCDKCalendarDaysNames (CDKCALENDAR *calendar, const char *days)
 {
    freeChar (calendar->DayName);
    calendar->DayName = copyChar (days);
@@ -880,7 +880,7 @@ static int getMonthStartWeekday (int year, int month)
    Date.tm_isdst = 1;
 
    /* Call the mktime function to fill in the holes. */
-   if (mktime (&Date) == (time_t) - 1)
+   if (mktime (&Date) == (time_t)-1)
    {
       return 0;
    }
@@ -937,21 +937,24 @@ static void incrementCalendarDay (CDKCALENDAR *calendar, int adjust)
  */
 static void decrementCalendarDay (CDKCALENDAR *calendar, int adjust)
 {
-   int monthLength;
-
    /* Make sure we adjust the day correctly. */
    if (calendar->day - adjust < 1)
    {
+      int monthLength;
+
       /* Set the day according to the length of the month. */
       if (calendar->month == 1)
       {
 	 /* Make sure we aren't going past the year limit. */
 	 if (calendar->year == 1900)
 	 {
-	    char *mesg[] =
-	    {"<C></U>Error", "Can not go past the year 1900"};
+	    const char *mesg[] =
+	    {
+	       "<C></U>Error",
+	       "Can not go past the year 1900"
+	    };
 	    Beep ();
-	    popupLabel (ScreenOf (calendar), mesg, 2);
+	    popupLabel (ScreenOf (calendar), (CDK_CSTRING2)mesg, 2);
 	    return;
 	 }
 	 monthLength = getMonthLength (calendar->year - 1, 12);
@@ -1018,10 +1021,13 @@ static void decrementCalendarMonth (CDKCALENDAR *calendar, int adjust)
    {
       if (calendar->year == 1900)
       {
-	 char *mesg[] =
-	 {"<C></U>Error", "Can not go past the year 1900"};
+	 const char *mesg[] =
+	 {
+	    "<C></U>Error",
+	    "Can not go past the year 1900"
+	 };
 	 Beep ();
-	 popupLabel (ScreenOf (calendar), mesg, 2);
+	 popupLabel (ScreenOf (calendar), (CDK_CSTRING2)mesg, 2);
 	 return;
       }
       else
@@ -1084,10 +1090,13 @@ static void decrementCalendarYear (CDKCALENDAR *calendar, int adjust)
    /* Make sure we don't go out of bounds. */
    if (calendar->year - adjust < 1900)
    {
-      char *mesg[] =
-      {"<C></U>Error", "Can not go past the year 1900"};
+      const char *mesg[] =
+      {
+	 "<C></U>Error",
+	 "Can not go past the year 1900"
+      };
       Beep ();
-      popupLabel (ScreenOf (calendar), mesg, 2);
+      popupLabel (ScreenOf (calendar), (CDK_CSTRING2)mesg, 2);
       return;
    }
 
@@ -1136,7 +1145,7 @@ static time_t getCurrentTime (CDKCALENDAR *calendar)
 
    /* Determine the current time and determine if we are in DST. */
    time (&clck);
-   dateInfo = localtime (&clck);
+   dateInfo = gmtime (&clck);
 
    /* *INDENT-EQLS* Set the tm structure correctly. */
    Date.tm_sec   = 0;
