@@ -1,9 +1,9 @@
-/* $Id: cdkscale.c,v 1.11 2011/05/16 22:58:54 tom Exp $ */
+/* $Id: cdkscale.c,v 1.15 2025/01/09 00:20:21 tom Exp $ */
 
 #include <cdk_test.h>
 
 #ifdef XCURSES
-char *XCursesProgramName="cdkscale";
+char *XCursesProgramName = "cdkscale";
 #endif
 
 /*
@@ -14,27 +14,26 @@ static int widgetCB (EObjectType cdktype, void *object, void *clientData, chtype
 /*
  * Define file local variables.
  */
-static char *FPUsage = "-f Field Width -l Low Value -h High Value [-s Initial Value]] [-i Increment Value] [-a Accelerated Increment Value] [-T Title] [-L Label] [-B Buttons] [-O Output File] [-X X Position] [-Y Y Position] [-N] [-S]";
+static const char *FPUsage = "-f Field Width -l Low Value -h High Value [-s Initial Value]] [-i Increment Value] [-a Accelerated Increment Value] [-T Title] [-L Label] [-B Buttons] [-O Output File] [-X X Position] [-Y Y Position] [-N] [-S]";
 
 /*
  *
  */
 int main (int argc, char **argv)
 {
-   /* Declare variables. */
-   CDKSCREEN *cdkScreen		= 0;
-   CDKSCALE *widget		= 0;
-   CDKBUTTONBOX *buttonWidget	= 0;
-   WINDOW *cursesWindow		= 0;
-   char *CDK_WIDGET_COLOR	= 0;
-   char *temp			= 0;
-   chtype *holder		= 0;
-   int answer			= 0;
-   int buttonCount		= 0;
-   int selection		= 0;
-   int shadowHeight		= 0;
-   FILE *fp			= stderr;
-   char **buttonList		= 0;
+   /* *INDENT-EQLS* */
+   CDKSCREEN *cdkScreen         = NULL;
+   CDKSCALE *widget             = NULL;
+   CDKBUTTONBOX *buttonWidget   = NULL;
+   char *CDK_WIDGET_COLOR       = NULL;
+   char *temp                   = NULL;
+   chtype *holder               = NULL;
+   int answer                   = 0;
+   int buttonCount              = 0;
+   int selection                = 0;
+   int shadowHeight             = 0;
+   FILE *fp                     = stderr;
+   char **buttonList            = NULL;
    int tmp, j1, j2;
 
    CDK_PARAMS params;
@@ -53,25 +52,25 @@ int main (int argc, char **argv)
    int xpos;
    int ypos;
 
-   CDKparseParams(argc, argv, &params, "a:f:h:i:l:s:B:L:O:T:" CDK_MIN_PARAMS);
+   CDKparseParams (argc, argv, &params, "a:f:h:i:l:s:B:L:O:T:" CDK_MIN_PARAMS);
 
-   xpos            = CDKparamValue(&params, 'X', CENTER);
-   ypos            = CDKparamValue(&params, 'Y', CENTER);
-   boxWidget       = CDKparamValue(&params, 'N', TRUE);
-   shadowWidget    = CDKparamValue(&params, 'S', FALSE);
+   /* *INDENT-EQLS* */
+   xpos            = CDKparamValue (&params, 'X', CENTER);
+   ypos            = CDKparamValue (&params, 'Y', CENTER);
+   boxWidget       = CDKparamValue (&params, 'N', TRUE);
+   shadowWidget    = CDKparamValue (&params, 'S', FALSE);
+   acceleratedStep = CDKparamValue (&params, 'a', -1);
+   fieldWidth      = CDKparamValue (&params, 'f', 0);
+   highValue       = CDKparamValue (&params, 'h', INT_MIN);
+   incrementStep   = CDKparamValue (&params, 'i', 1);
+   lowValue        = CDKparamValue (&params, 'l', INT_MAX);
+   initValue       = CDKparamValue (&params, 's', INT_MIN);
+   buttons         = CDKparamString (&params, 'B');
+   label           = CDKparamString (&params, 'L');
+   outputFile      = CDKparamString (&params, 'O');
+   title           = CDKparamString (&params, 'T');
 
-   acceleratedStep = CDKparamValue(&params, 'a', -1);
-   fieldWidth      = CDKparamValue(&params, 'f', 0);
-   highValue       = CDKparamValue(&params, 'h', INT_MIN);
-   incrementStep   = CDKparamValue(&params, 'i', 1);
-   lowValue        = CDKparamValue(&params, 'l', INT_MAX);
-   initValue       = CDKparamValue(&params, 's', INT_MIN);
-   buttons         = CDKparamString(&params, 'B');
-   label           = CDKparamString(&params, 'L');
-   outputFile      = CDKparamString(&params, 'O');
-   title           = CDKparamString(&params, 'T');
-
-   incrementStep   = abs(incrementStep);
+   incrementStep = abs (incrementStep);
 
    /* Make sure all the command line parameters were provided. */
    if (fieldWidth <= 0)
@@ -88,9 +87,9 @@ int main (int argc, char **argv)
    }
 
    /* If the user asked for an output file, try to open it. */
-   if (outputFile != 0)
+   if (outputFile != NULL)
    {
-      if ((fp = fopen (outputFile, "w")) == 0)
+      if ((fp = fopen (outputFile, "w")) == NULL)
       {
 	 fprintf (stderr, "%s: Can not open output file %s\n", argv[0], outputFile);
 	 ExitProgram (CLI_ERROR);
@@ -100,9 +99,10 @@ int main (int argc, char **argv)
    /* Make sure the low is lower than the high (and vice versa). */
    if (lowValue > highValue)
    {
-      tmp	= lowValue;
-      lowValue	= highValue;
-      highValue	= tmp;
+      /* *INDENT-EQLS* */
+      tmp       = lowValue;
+      lowValue  = highValue;
+      highValue = tmp;
    }
 
    /* Make sure the starting value is in range. */
@@ -122,15 +122,13 @@ int main (int argc, char **argv)
       acceleratedStep = MAXIMUM (1, acceleratedStep);
    }
 
-   /* Set up CDK. */
-   cursesWindow = initscr();
-   cdkScreen = initCDKScreen (cursesWindow);
+   cdkScreen = initCDKScreen (NULL);
 
    /* Start color. */
-   initCDKColor();
+   initCDKColor ();
 
    /* Check if the user wants to set the background of the main screen. */
-   if ((temp = getenv ("CDK_SCREEN_COLOR")) != 0)
+   if ((temp = getenv ("CDK_SCREEN_COLOR")) != NULL)
    {
       holder = char2Chtype (temp, &j1, &j2);
       wbkgd (cdkScreen->window, holder[0]);
@@ -139,46 +137,49 @@ int main (int argc, char **argv)
    }
 
    /* Get the widget color background color. */
-   if ((CDK_WIDGET_COLOR = getenv ("CDK_WIDGET_COLOR")) == 0)
+   if ((CDK_WIDGET_COLOR = getenv ("CDK_WIDGET_COLOR")) == NULL)
    {
-      CDK_WIDGET_COLOR = 0;
+      CDK_WIDGET_COLOR = NULL;
    }
 
    /* Create the entry widget. */
    widget = newCDKScale (cdkScreen, xpos, ypos,
-				title, label,
-				A_NORMAL, fieldWidth,
-				initValue, lowValue, highValue,
-				incrementStep, acceleratedStep,
-				boxWidget, shadowWidget);
+			 title, label,
+			 A_NORMAL, fieldWidth,
+			 initValue, lowValue, highValue,
+			 incrementStep, acceleratedStep,
+			 boxWidget, shadowWidget);
 
    /* Check to make sure we created the dialog box. */
-   if (widget == 0)
+   if (widget == NULL)
    {
       /* Shut down curses and CDK. */
       destroyCDKScreen (cdkScreen);
-      endCDK();
+      endCDK ();
 
-      fprintf (stderr, "Error: Could not create the numeric scale field. Is the window too small?\n");
+      fprintf (stderr,
+	       "Error: Could not create the numeric scale field. "
+	       "Is the window too small?\n");
 
       ExitProgram (CLI_ERROR);
    }
 
    /* Split the buttons if they supplied some. */
-   if (buttons != 0)
+   if (buttons != NULL)
    {
       /* Split the button list up. */
       buttonList = CDKsplitString (buttons, '\n');
-      buttonCount = (int)CDKcountStrings (buttonList);
+      buttonCount = (int)CDKcountStrings ((CDK_CSTRING2) buttonList);
 
       /* We need to create a buttonbox widget. */
       buttonWidget = newCDKButtonbox (cdkScreen,
-					getbegx (widget->win),
-					getbegy (widget->win) + widget->boxHeight - 1,
-					1, widget->boxWidth - 1,
-					0, 1, buttonCount,
-					buttonList, buttonCount,
-					A_REVERSE, boxWidget, FALSE);
+				      getbegx (widget->win),
+				      (getbegy (widget->win)
+				       + widget->boxHeight - 1),
+				      1, widget->boxWidth - 1,
+				      NULL, 1, buttonCount,
+				      (CDK_CSTRING2) buttonList, buttonCount,
+				      A_REVERSE, boxWidget, FALSE);
       CDKfreeStrings (buttonList);
 
       setCDKButtonboxULChar (buttonWidget, ACS_LTEE);
@@ -217,18 +218,18 @@ int main (int argc, char **argv)
    if (shadowWidget == TRUE)
    {
       /* Determine the height of the shadow window. */
-      shadowHeight = (buttonWidget == 0 ?
-			widget->boxHeight :
-			widget->boxHeight + buttonWidget->boxHeight - 1);
+      shadowHeight = (buttonWidget == NULL ?
+		      widget->boxHeight :
+		      widget->boxHeight + buttonWidget->boxHeight - 1);
 
       /* Create the shadow window. */
       widget->shadowWin = newwin (shadowHeight,
-					widget->boxWidth,
-					getbegy (widget->win) + 1,
-					getbegx (widget->win) + 1);
+				  widget->boxWidth,
+				  getbegy (widget->win) + 1,
+				  getbegx (widget->win) + 1);
 
       /* Make sure we could have created the shadow window. */
-      if (widget->shadowWin != 0)
+      if (widget->shadowWin != NULL)
       {
 	 widget->shadow = TRUE;
 
@@ -237,9 +238,9 @@ int main (int argc, char **argv)
 	  * buttonbox widget will be drawn when the widget is activated.
 	  * Otherwise the shadow window will draw over the button widget.
 	  */
-	 drawCDKScale (widget, ObjOf(widget)->box);
+	 drawCDKScale (widget, ObjOf (widget)->box);
 	 eraseCDKButtonbox (buttonWidget);
-	 drawCDKButtonbox (buttonWidget, ObjOf(buttonWidget)->box);
+	 drawCDKButtonbox (buttonWidget, ObjOf (buttonWidget)->box);
       }
    }
 
@@ -247,10 +248,10 @@ int main (int argc, char **argv)
    setCDKScaleBackgroundColor (widget, CDK_WIDGET_COLOR);
 
    /* Activate the widget. */
-   answer = activateCDKScale (widget, 0);
+   answer = activateCDKScale (widget, NULL);
 
    /* If there were buttons, get the button selected. */
-   if (buttonWidget != 0)
+   if (buttonWidget != NULL)
    {
       selection = buttonWidget->currentButton;
       destroyCDKButtonbox (buttonWidget);
@@ -259,7 +260,7 @@ int main (int argc, char **argv)
    /* End CDK. */
    destroyCDKScale (widget);
    destroyCDKScreen (cdkScreen);
-   endCDK();
+   endCDK ();
 
    /* Print the value from the widget. */
    fprintf (fp, "%d\n", answer);
@@ -269,9 +270,12 @@ int main (int argc, char **argv)
    ExitProgram (selection);
 }
 
-static int widgetCB (EObjectType cdktype GCC_UNUSED, void *object GCC_UNUSED, void *clientData, chtype key)
+static int widgetCB (EObjectType cdktype GCC_UNUSED,
+		     void *object GCC_UNUSED,
+		     void *clientData,
+		     chtype key)
 {
    CDKBUTTONBOX *buttonbox = (CDKBUTTONBOX *)clientData;
-   injectCDKButtonbox (buttonbox, key);
+   (void) injectCDKButtonbox (buttonbox, key);
    return (TRUE);
 }
